Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(9)

Unified Diff: third_party/WebKit/Source/web/WebLocalFrameImpl.h

Issue 2886113002: Introduce WebPluginContainerBase to abstract WebPluginContainerImpl. (Closed)
Patch Set: Rebase Created 3 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/web/WebLocalFrameImpl.h
diff --git a/third_party/WebKit/Source/web/WebLocalFrameImpl.h b/third_party/WebKit/Source/web/WebLocalFrameImpl.h
index e84828ea9d202821939ca834e654b94632d08ebd..e532d8d460e115173776254c1c1a40a0d0bc212c 100644
--- a/third_party/WebKit/Source/web/WebLocalFrameImpl.h
+++ b/third_party/WebKit/Source/web/WebLocalFrameImpl.h
@@ -70,7 +70,7 @@ class WebInputMethodControllerImpl;
class WebNode;
class WebPerformance;
class WebPlugin;
-class WebPluginContainerImpl;
+class WebPluginContainerBase;
class WebScriptExecutionCallback;
class WebView;
class WebViewBase;
@@ -352,14 +352,14 @@ class WEB_EXPORT WebLocalFrameImpl final
static WebLocalFrameImpl* FromFrameOwnerElement(Element*);
// If the frame hosts a PluginDocument, this method returns the
- // WebPluginContainerImpl that hosts the plugin.
- static WebPluginContainerImpl* PluginContainerFromFrame(LocalFrame*);
+ // WebPluginContainerBase that hosts the plugin.
+ static WebPluginContainerBase* PluginContainerFromFrame(LocalFrame*);
// If the frame hosts a PluginDocument, this method returns the
// WebPluginContainerImpl that hosts the plugin. If the provided node is a
// plugin, then it runs its WebPluginContainerImpl. Otherwise, uses the
// currently focused element (if any).
- static WebPluginContainerImpl* CurrentPluginContainer(LocalFrame*,
+ static WebPluginContainerBase* CurrentPluginContainer(LocalFrame*,
Node* = nullptr);
WebViewBase* ViewImpl() const override;
@@ -352,14 +352,14 @@ class WEB_EXPORT WebLocalFrameImpl final
// If the frame hosts a PluginDocument, this method returns the
- // WebPluginContainerImpl that hosts the plugin. If the provided node is a
- // plugin, then it runs its WebPluginContainerImpl. Otherwise, uses the
+ // WebPluginContainerBase that hosts the plugin. If the provided node is a
+ // plugin, then it runs its WebPluginContainerBase. Otherwise, uses the
// currently focused element (if any).

Powered by Google App Engine
This is Rietveld 408576698